@@ -3,7 +3,7 @@ package X11::Terminal::GnomeTerminal;
 use Moose;
 extends 'X11::Terminal';
 
-our $VERSION = 0.4;
+our $VERSION = 1.0.0;
 
 =head1 NAME
 
@@ -30,14 +30,16 @@ This module provides an object interface to launching gnome-terminal windows.
 
 =item X11::Terminal::GnomeTerminal->new(%attr);
 
-Create a new GnomeTerminal object, optionally with the specified attributes (see below).
+Create a new GnomeTerminal object, optionally with the specified attributes
+(see below).
 
 =back
 
 
 =head1 ATTRIBUTES
 
-Each of the following attributes provide an accessor method, but they can also be set in the constructor.
+Each of the following attributes provide an accessor method, but they can
+also be set in the constructor.
 
 =over 4
  
@@ -47,11 +49,13 @@ Specifies the remote host to log in to (using ssh).
 
 =item agentforward
 
-If the host has been specified, and agentforward is true, the login to that host will use SSH Agent Forarding.
+If the host has been specified, and agentforward is true, the login to that
+host will use SSH Agent Forwarding.
 
 =item xforward
 
-If the host has been specified, and xforward is true, the login to that host will use SSH X Forarding.
+If the host has been specified, and xforward is true, the login to that host
+will use SSH X Forwarding.
 
 =item profile
 
@@ -70,33 +74,37 @@ Set the preferred size and position of the GnomeTerminal window
 
 =item launch($debug);
 
-Calculates (and returns) the command that will launch your gnome-terminal.  It also runs that command in a child process - unless $debug is specified.
+Calculates (and returns) the command that will launch your gnome-terminal.
+It also runs that command in a child process - unless $debug is specified.
 
 =item terminalArgs();
 
-Return the arguments that will be passed to the gnome-terminal.  This will provide the customisations.  There should be no reason to call this method directly.
+Return the arguments that will be passed to the gnome-terminal.  This will
+provide the customisations.  There should be no reason to call this method
+directly.
 =cut
 
 sub terminalArgs {
-  my ($self) = @_;
+    my ($self) = @_;
 
-  my $args = "";
-  if ( my $name = $self->profile() ) {
-    $args .= " --window-with-profile=$name";
-  }
-  if ( my $geo = $self->geometry() ) {
-    $args .= " -geometry $geo";
-  }
-  return "$args";
+    my $args = "";
+    if ( my $name = $self->profile() ) {
+        $args .= " --window-with-profile=$name";
+    }
+    if ( my $geo = $self->geometry() ) {
+        $args .= " -geometry $geo";
+    }
+    return "$args";
 }
 
 =item terminalName();
 
-Returns the name of the executable program that we want to run.  There should be no reason to call this method directly.
+Returns the name of the executable program that we want to run.  There
+should be no reason to call this method directly.
 =cut
 
 sub terminalName {
-  return "gnome-terminal";
+    return "gnome-terminal";
 }
 
 =back
@@ -113,4 +121,4 @@ This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 =cut
 
-1; # End of X11::Terminal::GnomeTerminal
+1;    # End of X11::Terminal::GnomeTerminal
