@@ -3,7 +3,7 @@ package X11::Terminal::XTerm;
 use Moose;
 extends 'X11::Terminal';
 
-our $VERSION = 0.4;
+our $VERSION = 1.0.0;
 
 =head1 NAME
 
@@ -30,14 +30,16 @@ This module provides an object interface to launching xterm windows.
 
 =item X11::Terminal::XTerm->new(%attr);
 
-Create a new XTerm object, optionally with the specified attributes (see below).
+Create a new XTerm object, optionally with the specified attributes
+(see below).
 
 =back
 
 
 =head1 ATTRIBUTES
 
-Each of the following attributes provide an accessor method, but they can also be set in the constructor.
+Each of the following attributes provide an accessor method, but they can
+also be set in the constructor.
 
 =over 4
  
@@ -47,11 +49,13 @@ Specifies the remote host to log in to (using ssh).
 
 =item agentforward
 
-If the host has been specified, and agentforward is true, the login to that host will use SSH Agent Forarding.
+If the host has been specified, and agentforward is true, the login to that
+host will use SSH Agent Forwarding.
 
 =item xforward
 
-If the host has been specified, and xforward is true, the login to that host will use SSH X Forarding.
+If the host has been specified, and xforward is true, the login to that host
+will use SSH X Forwarding.
 
 =item foreground
 
@@ -63,7 +67,8 @@ Set the background colour to be used in the XTerm window
 
 =item scrollback
 
-Set the number of lines that should be stored made accessable via the xterm scrollback buffer
+Set the number of lines that should be stored made accessible via the xterm
+scrollback buffer
 
 =item font
 
@@ -86,36 +91,38 @@ Set the preferred size and position of the XTerm window
 
 =item launch($debug);
 
-Calculates (and returns) the command that will launch your xterm.  It also runs that command in a child process - unless $debug is specified.
+Calculates (and returns) the command that will launch your xterm.  It also
+runs that command in a child process - unless $debug is specified.
 
 =item terminalArgs();
 
-Return the arguments that will be passed to the xterm.  This will provide the customisations.  There should be no reason to call this method directly.
+Return the arguments that will be passed to the xterm.  This will provide
+the customisations.  There should be no reason to call this method directly.
 =cut
 
 sub terminalArgs {
-  my ($self) = @_;
+    my ($self) = @_;
 
-  my $args = "";
-  if ( my $font = $self->font() ) {
-    $args .= " -fn $font";
-  }
-  if ( my $name = $self->profile() ) {
-    $args .= " -name $name";
-  }
-  if ( my $colour = $self->foreground() ) {
-    $args .= " -fg $colour";
-  }
-  if ( my $geo = $self->geometry() ) {
-    $args .= " -geometry $geo";
-  }
-  if ( my $colour = $self->background() ) {
-    $args .= " -bg $colour";
-  }
-  if ( my $lines = $self->scrollback() ) {
-    $args .= " -sl $lines";
-  }
-  return "$args";
+    my $args = "";
+    if ( my $font = $self->font() ) {
+        $args .= " -fn $font";
+    }
+    if ( my $name = $self->profile() ) {
+        $args .= " -name $name";
+    }
+    if ( my $colour = $self->foreground() ) {
+        $args .= " -fg $colour";
+    }
+    if ( my $geo = $self->geometry() ) {
+        $args .= " -geometry $geo";
+    }
+    if ( my $colour = $self->background() ) {
+        $args .= " -bg $colour";
+    }
+    if ( my $lines = $self->scrollback() ) {
+        $args .= " -sl $lines";
+    }
+    return "$args";
 }
 
 =back
@@ -132,4 +139,4 @@ This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 =cut
 
-1; # End of X11::Terminal::XTerm
+1;    # End of X11::Terminal::XTerm
